<?php

declare(strict_types=1);

namespace apexl\Io\modules\user\exceptions;

/** The method is temporarily locked after too many failed attempts. */
class TwoFactorLockedException extends TwoFactorException
{
}
